==> beacon_0_1_2.zip: beacon/beacon/inc/footer.inc.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of beacon
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


// TEMPLATE OUTPUT ---------------------------------------------------------
// error reporting
if (!empty($GLOBALS['beacon_error_log'])) {
    $tpl->set('log', $GLOBALS['beacon_error_log']);
}

// language
$tpl->set('lang', $lang);
$body->set('lang', $lang);
// general interface, url and template
$tpl->set('templatePath', $template_path);
$body->set('templatePath', $template_path);
$tpl->set('link_type_ids', $c_node['menu']['link_type']);
$tpl->user = $user;
$body->user = $user;
$tpl->set('permissions', $c_node['permission']);
$body->set('permissions', $c_node['permission']);

// PROCESS TEMPLATE ---------------------------------------------------------
if (!isset($template_file)) {
	$template_file = "index.tpl.php";
}
$tpl->set('content', $body->fetch($template_file));
echo $tpl->fetch('default.tpl.php');

	

// TIDY UP -----------------------------------------------------------------------
$db->Close();

?>

==> beacon_0_1_4.zip: beacon/beacon/inc/footer.inc.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of beacon
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


// TEMPLATE OUTPUT ---------------------------------------------------------
// error reporting
if (!empty($GLOBALS['beacon_error_log'])) {
    $tpl->set('log', $GLOBALS['beacon_error_log']);
}

//for checking permissions we need to make sure that the user_id is mine
if (isset($_SESSION['user_id']) && isset($user)) {
	$user->user_id = $_SESSION['user_id'];
}

// language
$tpl->set('lang', $lang);
$body->set('lang', $lang);
// general interface, url and template
$tpl->set('templatePath', $template_path);
$body->set('templatePath', $template_path);
$tpl->set('link_type_ids', $c_node['menu']['link_type']);
$tpl->user = $user;
$body->user = $user;
$tpl->set('permissions', $c_node['permission']);
$body->set('permissions', $c_node['permission']);

// PROCESS TEMPLATE ---------------------------------------------------------
if (!isset($template_file)) {
	$template_file = "index.tpl.php";
}
$tpl->set('content', $body->fetch($template_file));
echo $tpl->fetch('default.tpl.php');

	

// TIDY UP -----------------------------------------------------------------------
$db->Close();

?>
